#
# Repository
#

resource "aws_ecr_repository" "default" {
  name = "${var.namespace}/${var.name}"
}

#
# Lifecycle:
# - remove untagged
# - keep max `max_images_count` images
#

resource "aws_ecr_lifecycle_policy" "default" {
  repository = aws_ecr_repository.default.name

  policy = <<EOF
{
  "rules": [
    {
      "rulePriority": 1,
      "description": "Remove untagged images.",
      "selection": {
        "tagStatus": "untagged",
        "countType": "imageCountMoreThan",
        "countNumber": 1
      },
      "action": {
        "type": "expire"
      }
    },
    {
      "rulePriority": 2,
      "description": "Rotate images when reach ${var.max_images_count} images stored.",
      "selection": {
        "tagStatus": "any",
        "countType": "imageCountMoreThan",
        "countNumber": ${var.max_images_count}
      },
      "action": {
        "type": "expire"
      }
    }
  ]
}
EOF
}
