#
# Generate RSA SSH key
#

resource "tls_private_key" "swarm_ssh_key" {
  algorithm = "RSA"
  rsa_bits = 2048
}

#
# Store key as local files
#

resource "local_file" "ssh-key-public" {
  content = tls_private_key.swarm_ssh_key.public_key_openssh
  filename = "${var.env}-${var.ssh_key_name}.pub"

  depends_on = [
    tls_private_key.swarm_ssh_key,
  ]
}
resource "local_file" "ssh-key-private" {
  sensitive_content = tls_private_key.swarm_ssh_key.private_key_pem
  filename = "${var.env}-${var.ssh_key_name}.pem"
  file_permission = "0600"

  depends_on = [
    tls_private_key.swarm_ssh_key,
  ]
}

#
# AWS keypair
#

resource "aws_key_pair" "swarm_ssh_key" {
  key_name = "${var.env}-${var.ssh_key_name}"
  public_key = tls_private_key.swarm_ssh_key.public_key_openssh

  depends_on = [
    tls_private_key.swarm_ssh_key,
  ]
}
