resource "aws_instance" "worker" {
  count                       = var.workers_count
  ami                         = module.amzn2_docker_ami.ami_id
  instance_type               = var.worker_instance_type
  associate_public_ip_address = true

  subnet_id = element(var.jz_vpc.subnets.*.id, count.index % 3)

  key_name             = var.jz_swarm_generic.ssh_key_pair.key_name
  iam_instance_profile = var.jz_swarm_global.iam_profiles.swarm_worker.name

  vpc_security_group_ids = flatten([
    var.jz_swarm_generic.security_groups.*.id,
    var.app_security_groups.*.id,
    aws_security_group.app.id,
    aws_security_group.dev.id,
  ])

  root_block_device {
    volume_size = var.ebs_size
  }

  tags = {
    Name = "${var.name}-${var.env}-worker-${count.index}"
    Env  = var.env
  }

  depends_on = [
    aws_instance.leader,
  ]

  lifecycle {
    ignore_changes = [
      ami,
      root_block_device,
      instance_type,
      ebs_optimized,
    ]
  }
}
